@@ -89,7 +89,7 @@ class Builder:
             print("Navbar not found!")  # TODO Handle this better
             return []
 
-        simplify.docs.Docs(navbar, self.creds)
+        gsimplify.docs.Docs(navbar, self.creds)
 
         sections = navbar.content['body']['content']
 
@@ -172,6 +172,8 @@ class Builder:
                     pbar.close()
 
         if self.assets_dir:
+            if os.path.exists(f"./build/{self.fetch_commit()}/assets/"):
+                shutil.rmtree(f"./build/{self.fetch_commit()}/assets/")
             shutil.copytree(self.assets_dir, f"./build/{self.fetch_commit()}/assets/")
 
         shutil.rmtree("./build/latest", ignore_errors=True)
